==> ibus-1.3.9.tgz: include/ibus-1.0/ibus.h <==
/* -*- mode: C; c-basic-offset: 4; indent-tabs-mode: nil; -*- */
/* vim:set et sts=4: */
/* ibus - The Input Bus
 * Copyright (C) 2008-2010 Peng Huang <shawn.p.huang@gmail.com>
 * Copyright (C) 2008-2010 Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __IBUS_H_
#define __IBUS_H_

#include <ibusversion.h>
#include <ibusmainloop.h>
#include <ibusshare.h>
#include <ibusobject.h>
#include <ibusserializable.h>
#include <ibusattribute.h>
#include <ibusattrlist.h>
#include <ibustext.h>
#include <ibusconnection.h>
#include <ibusserver.h>
#include <ibusproxy.h>
#include <ibusservice.h>
#include <ibusfactory.h>
#include <ibusengine.h>
#include <ibusproperty.h>
#include <ibusproplist.h>
#include <ibuslookuptable.h>
#include <ibusbus.h>
#include <ibuskeysyms.h>
#include <ibuskeymap.h>
#include <ibusmessage.h>
#include <ibuspendingcall.h>
#include <ibuserror.h>
#include <ibusenumtypes.h>
#include <ibushotkey.h>
#include <ibusxml.h>
#include <ibusenginedesc.h>
#include <ibusobservedpath.h>
#include <ibuscomponent.h>
#include <ibusconfig.h>
#include <ibusconfigservice.h>
#include <ibusmainloop.h>

#endif

==> ibus-1.4.0p0.tgz: include/ibus-1.0/ibus.h <==
/* -*- mode: C; c-basic-offset: 4; indent-tabs-mode: nil; -*- */
/* vim:set et sts=4: */
/* ibus - The Input Bus
 * Copyright (C) 2008-2010 Peng Huang <shawn.p.huang@gmail.com>
 * Copyright (C) 2008-2010 Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __IBUS_H_
#define __IBUS_H_

#define __IBUS_H_INSIDE__

#include <ibusversion.h>
#include <ibusshare.h>
#include <ibusobject.h>
#include <ibusserializable.h>
#include <ibusattribute.h>
#include <ibusattrlist.h>
#include <ibustext.h>
#include <ibusproxy.h>
#include <ibusservice.h>
#include <ibusfactory.h>
#include <ibusengine.h>
#include <ibuserror.h>
#include <ibusproperty.h>
#include <ibusproplist.h>
#include <ibuslookuptable.h>
#include <ibusbus.h>
#include <ibuskeysyms.h>
#include <ibuskeymap.h>
#include <ibuskeys.h>
#include <ibusenumtypes.h>
#include <ibushotkey.h>
#include <ibusxml.h>
#include <ibusenginedesc.h>
#include <ibusobservedpath.h>
#include <ibuscomponent.h>
#include <ibusconfig.h>
#include <ibusconfigservice.h>
#include <ibuspanelservice.h>

#undef __IBUS_H_INSIDE__

#endif
